pub enum StateTransitionSystems {
DependentTransitions,
ExitSchedules,
TransitionSchedules,
EnterSchedules,
}Expand description
Applies state transitions and runs transitions schedules in order.
These system sets are run sequentially, in the order of the enum variants.
Variants
DependentTransitions
States apply their transitions from NextState
and compute functions based on their parent states.
ExitSchedules
Exit schedules are executed in leaf to root order
TransitionSchedules
Transition schedules are executed in arbitrary order.
EnterSchedules
Enter schedules are executed in root to leaf order.